#!/bin/bash
cd bindings/js/wasm
cargo c
cd ../..
